@@ -216,5 +216,26 @@ def mutate_input_version(
 	return results
 
 
+def instantiate(
+			fqn,
+			field_name,
+			definition_or_name,
+			version=Utils.Empty,
+			validate=True,
+			rules_kw={},
+			**initial_values
+		):
+	result = Definitions.Index.instantiate(
+			fqn,
+			field_name,
+			definition_or_name,
+			version,
+			validate,
+			rules_kw,
+			**initial_values
+		)
+	return result
+
+
 def clear():
 	Definitions.Index.clear()
