@@ -3,6 +3,7 @@ def initialize():
 	import cro_validate.classes.example_generator_classes as Examples
 	import cro_validate.classes.name_resolver_classes as NameResolvers
 	import cro_validate.classes.name_strategy_classes as NameStrategies
+	import cro_validate.classes.definition_classes as Definitions
 	from cro_validate.classes.configuration_classes import Config
 
 	Config.exception_factory = Exceptions.DefaultExceptionFactory()
@@ -11,5 +12,6 @@ def initialize():
 	Config.definition_name_resolver = NameResolvers.DefaultNameResolver()
 	Config.parameter_name_resolver = NameResolvers.DefaultNameResolver()
 	Config.definition_name_strategy = NameStrategies.DefaultDefinitionNameStrategy()
+	Config.instantiate_value_provider = Definitions.InstantiateValueProvider()
 
 initialize()
\ No newline at end of file
