@@ -9,7 +9,7 @@ import cro_validate.classes.name_strategy_classes as NameStrategies
 import cro_validate.classes.util_classes as Utils
 
 
-def instantiate(fqn, *args, **kw):
+def instantiate_class(fqn, *args, **kw):
 	module_name, class_name = Utils.ClassName.class_fqn_parts(fqn)
 	if module_name == 'builtins' and class_name == 'NoneType':
 		return None
@@ -36,7 +36,6 @@ class DefaultDefinitionMeta(Meta):
 		if not Utils.Empty.isempty(component_name_strategy):
 			self.component_name_strategy = component_name_strategy
 
-
 	def initialize(self, definition, component_name_suffix='Model', display_name=None):
 		if definition.is_object():
 			self.schema_name = definition.data_format.model_name
@@ -47,6 +46,58 @@ class DefaultDefinitionMeta(Meta):
 			self.component_name = self.component_name_strategy.create_name(definition, component_name_suffix, display_name)
 
 
+class InstantiateValueProvider:
+	def __init__(self):
+		pass
+
+	def __call__(self, fqn, field_name, definition, data_type, data_format):
+		try:
+			if field_name is None:
+				field_name = definition.get_name()
+			if fqn is None:
+				fqn = field_name
+			if definition.is_object() is True:
+				result = Parameters.Index()
+				fields = definition.list_fields()
+				for k in fields:
+					f = fields[k]
+					field_definition = Index.get(
+							f.definition_name,
+							version=definition.version
+						)
+					field_fqn = Config.definition_name_strategy.get_fqn(fqn, k)
+					result[k] = Config.instantiate_value_provider(
+							field_fqn,
+							k,
+							field_definition,
+							field_definition.get_data_type(),
+							field_definition.get_data_format()
+						)
+				return result
+			if definition.is_array():
+				return []
+			if definition.is_nullable() is True:
+				return None
+			if data_type is DataType.Integer:
+				return 0
+			if data_type is DataType.String:
+				return ''
+			if data_type is DataType.Float:
+				return 0.0
+			if data_type is DataType.Boolean:
+				return False
+		except Exception as ex:
+			raise Config.exception_factory.create_internal_error(
+					fqn,
+					'Failed to instantiate.',
+					ex
+				)
+		raise Config.exception_factory.create_internal_error(
+				fqn,
+				"This default value provider doesn't support {0}.".format(data_type)
+			)
+
+
 class Definition:
 	name = None
 	aliases = []
@@ -321,11 +372,28 @@ class Definition:
 			return False
 		return True
 
-	def get_default_value(self, field_name=None):
+	def get_default_value(self, fqn=None):
+		if fqn is None:
+			fqn = self.name
+		if self.is_array() is True:
+			if self.is_nullable() is True:
+				return None
+			return []
+		if self.is_object() is True:
+			if self.is_nullable() is True:
+				return None
+			result = Parameters.Index()
+			fields = self.list_fields()
+			for k in fields:
+				f = fields[k]
+				field_definition = Index.get(f.definition_name, version=self.version)
+				if field_definition.has_default_value() is not True and field_definition.is_primitive() is True:
+					field_fqn = Config.definition_name_strategy.get_fqn(fqn, k)
+					raise Config.exception_factory.create_internal_error(field_fqn, 'No default value configured')
+				result[k] = field_definition.get_default_value()
+			return result
 		if not self.has_default_value():
-			if field_name is None:
-				field_name = self.name
-			raise Config.exception_factory.create_internal_error(field_name, 'No default value configured')
+			raise Config.exception_factory.create_internal_error(fqn, 'No default value configured')
 		return self.default_value
 
 	def get_name(self):
@@ -470,8 +538,15 @@ class DefinitionJsonDeserializer:
 	def _deserialize_schema_field(self, name, obj):
 		kw = {}
 		if 'default_value' in obj:
-			if obj['default_value_type'] != 'cro_validate.classes.util_classes.Empty':
-				kw['default_value'] = instantiate(obj['default_value_type'], obj['default_value'])
+			#if obj['default_value_type'] == '<definition_name>':
+			#	default_value_definition_name = obj['default_value']
+			#	if not Index.exists(default_value_definition_name):
+			#		dependent_definition_profile = self.deserialize(default_value_definition_name)
+			#		Index.register_definition(**dependent_definition_profile)
+			#	kw['default_value'] = instantiate_class(obj['default_value_type'], obj['default_value'])
+			#elif obj['default_value_type'] != 'cro_validate.classes.util_classes.Empty':
+			#	kw['default_value'] = instantiate_class(obj['default_value_type'], obj['default_value'])
+			kw['default_value'] = instantiate_class(obj['default_value_type'], obj['default_value'])
 		kw['definition_name'] = name
 		if 'definition_name' in obj and obj['definition_name'] is not None:
 			kw['definition_name'] = obj['definition_name']
@@ -505,7 +580,7 @@ class DefinitionJsonDeserializer:
 				if 'kw' in entry:
 					init_action_kw = entry['kw']
 				init_action_class_name = entry['type']
-				init_action = instantiate(init_action_class_name, **init_action_kw)
+				init_action = instantiate_class(init_action_class_name, **init_action_kw)
 				field_init_actions.append(init_action)
 		kw['field_init_actions'] = field_init_actions
 		if 'dependency_resolver' in obj:
@@ -513,7 +588,7 @@ class DefinitionJsonDeserializer:
 			resolver_kw = {}
 			if 'kw' in obj['dependency_resolver']:
 				resolver_kw = obj['dependency_resolver']['kw']
-			resolver = instantiate(resolver_class_name, **resolver_kw)
+			resolver = instantiate_class(resolver_class_name, **resolver_kw)
 			kw['dependency_resolver'] = resolver
 		if 'inherits' in obj:
 			for inherited_definition_name in obj['inherits']:
@@ -534,7 +609,7 @@ class DefinitionJsonDeserializer:
 		return schema
 
 	def _deserialize_rule(self, obj):
-		rule = instantiate(obj['type'], **obj['config'])
+		rule = instantiate_class(obj['type'], **obj['config'])
 		return rule
 
 	def _deserialize_version(self, obj):
@@ -566,7 +641,7 @@ class DefinitionJsonDeserializer:
 		if 'conversion' in obj:
 			config = obj['conversion']['config']
 			type_fqn = obj['conversion']['type']
-			conversion = instantiate(type_fqn, **config)
+			conversion = instantiate_class(type_fqn, **config)
 			result['conversion'] = conversion
 		return result
 
@@ -594,14 +669,14 @@ class DefinitionJsonDeserializer:
 			if obj['data_format_type'] == 'cro_validate.classes.schema_classes.Schema':
 				kw['data_format'] = self._deserialize_schema(obj['data_format'], name)
 			else:
-				kw['data_format'] = instantiate(obj['data_format_type'], obj['data_format'])
+				kw['data_format'] = instantiate_class(obj['data_format_type'], obj['data_format'])
 		# Default Value
 		###############
 		if 'default_value' in obj:
 			if obj['default_value_type'] == 'builtins.NoneType':
 				kw['default_value'] = None
 			elif obj['default_value_type'] != 'cro_validate.classes.util_classes.Empty':
-				kw['default_value'] = instantiate(obj['default_value_type'], obj['default_value'])
+				kw['default_value'] = instantiate_class(obj['default_value_type'], obj['default_value'])
 		# Rules
 		#######
 		if 'rules' in obj:
@@ -628,7 +703,7 @@ class DefinitionJsonDeserializer:
 		if 'base_version_conversion' in obj:
 			config = obj['base_version_conversion']['config']
 			type_fqn = obj['base_version_conversion']['type']
-			kw['base_version_conversion'] = instantiate(type_fqn, **config)
+			kw['base_version_conversion'] = instantiate_class(type_fqn, **config)
 		if 'versions' in obj:
 			kw['versions'] = {}
 			for version in obj['versions']:
@@ -820,6 +895,43 @@ class Index:
 
 		return versions[version]
 
+	def instantiate(
+				fqn,
+				field_name,
+				definition_or_name,
+				version=Utils.Empty,
+				validate=True,
+				rules_kw={},
+				**initial_values
+			):
+		definition = Index.get(definition_or_name, version)
+		if field_name is None:
+			field_name = definition.get_name()
+		if fqn is None:
+			fqn = field_name
+		value = Config.instantiate_value_provider(
+				fqn,
+				field_name,
+				definition,
+				definition.get_data_type(),
+				definition.get_data_format()
+			)
+		if definition.is_object() is True:
+			value.update(initial_values)
+		if validate is True:
+			result = Index.validate(
+					None,
+					fqn,
+					field_name,
+					definition,
+					value,
+					version,
+					ValidationMode.Input,
+					**rules_kw
+				)
+			return result[definition.get_name()]
+		return value
+
 	def exists(definition_name):
 		resolved = Index._resolve_definition_name(
 				definition_name,
