@@ -10,14 +10,6 @@ class SetFieldsRequired:
 		if field_list is not None:
 			self.field_list.update(field_list)
 
-	def validate_schema_model(self, model):
-		for field_name in self.field_list:
-			if field_name not in model:
-				raise Config.exception_factory.create_internal_error(
-						field_name,
-						'Field not found in model.'
-					)
-
 	def __call__(self, field_name, field):
 		if field_name in self.field_list:
 			field.required = self.required
@@ -37,20 +29,6 @@ class OmitFields:
 		if field_white_list is not None:
 			self.field_white_list.update(field_white_list)
 
-	def validate_schema_model(self, model):
-		for field_name in self.field_list:
-			if field_name not in model:
-				raise Config.exception_factory.create_internal_error(
-						field_name,
-						'Field from field_list not found in model.'
-					)
-		for field_name in self.field_white_list:
-			if field_name not in model:
-				raise Config.exception_factory.create_internal_error(
-						field_name,
-						'Field from field_white_list not found in model.'
-					)
-
 	def __call__(self, field_name, field):
 		if field_name in self.field_white_list:
 			return field
