@@ -1,13 +1,24 @@
 from cro_validate.classes.configuration_classes import Config
 
 
+class NamedAttributeError(AttributeError):
+	def __init__(self, name):
+		self.name = name
+
+	def __str__(self):
+		return ('Object missing attribute "{0}"'.format(self.name))
+
+	def __repr__(self):
+		return self.__str__()
+
+
 class Index(dict):
 	def __getattr__(self, name):
 		resolved = Config.parameter_name_resolver.resolve(self, name)
 		if resolved is None:
 			#raise Config.exception_factory.create_input_error(name, 'Unresolved name.')
 			#raise Config.exception_factory.create_internal_error(name, 'Unresolved name.')
-			raise AttributeError() # to comply with hasattr
+			raise NamedAttributeError(name) # to comply with hasattr
 		result = self[resolved]
 		return result
 
