@@ -542,19 +542,19 @@ class ModelValidator:
 			if self.schema.case_sensitive is False:
 				values = {k.lower():values[k] for k in values}
 			normalized = Parameters.Index(values)
-		field_names = self._list_field_names_for_input(normalized)
-		kw = Parameters.Index()
-		missing = set(self.required)
 		# Build kw
 		##########
+		kw = Parameters.Index()
 		if self.schema.load_defaults is True:
 			for field_name in self.optional:
 				if field_name in self.default_values:
 					kw[field_name] = self.default_values[field_name]
+		field_names = self._list_field_names_for_input(normalized)
+		missing = set(self.required)
 		for field_name in field_names:
 			if field_name in missing:
 				missing.remove(field_name)
-			elif field_name not in self.optional:
+			elif field_name not in kw and field_name not in self.optional:
 				if not self.schema.allow_unknown_fields:
 					display_name = self.get_field_input_display_name(field_name)
 					raise Config.exception_factory.create_input_error(Config.definition_name_strategy.get_fqn(fqn, display_name), 'Unknown field.')
